==> em_celery-0.1.42-py2.py3-none-any.whl: em_celery/tools/spree/product_importer.py <==
# -*- coding: utf-8 -*-

import datetime
import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.api import SpreeApi
from em_tasks.utils.blacklist_filter import BlacklistFilter
from em_tasks.store.models import *

from em_celery import logger, init_db


@click.command('Import products to Spree')
@click.option('-s', '--store_code', type=str, required=True)
@click.option('-ms', '--min_shipping_days', type=int, default=7, help='Minimum shipping days, default is 7.')
@click.option('-tn', '--taxonomy_name', type=str, default='Categories', help='Spree taxonomy name, default is "Categories".')
@click.option('-m', '--merchant_id', required=True, type=str, help='Google Merchant ID to upload to.')
@click.option('-v', '--vendor_id', required=True, type=str, help='Vendor ID that products belongs to.')
@click.option('-tc', '--tax_category_id', type=int, default=1, help='Spree tax category ID, default is 1.')
@click.option('-sl', '--stock_location_id', required=True, type=int, help='Spree stock location ID.')
@click.option('-sc', '--shipping_category_id', required=True, type=int, help='Spree shipping category ID.')
@click.argument('products_path')
def import_products(store_code, products_path, shipping_category_id, stock_location_id, merchant_id, vendor_id, tax_category_id=1, taxonomy_name='Categories', min_shipping_days=7):
  init_db()

  if not products_path:
    return

  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    return

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    return

  blacklist_filter = BlacklistFilter()

  credential = json.loads(store.api_credential)
  spree_api = SpreeApi(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
  # spree_api = SpreeApi('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))

  blacklisted_cnt = 0
  to_upload_cnt = 0

  batch_size = 50
  products_buf = []
  with open(products_path, encoding='utf-8', errors='ignore') as fh:
    for line in fh:
      s = line.strip()
      if not s:
        continue

      prod = None
      try:
        prod = json.loads(s)
      except Exception as e:
        logger.exception(e)

      if not prod:
        continue

      brand = prod.get('brand', None)
      title = prod.get('title_en', None) or prod.get('title', '')
      if brand:
        s = '{} -{}'.format(brand.lower(), title.lower())
      else:
        s = title.lower()
      result = blacklist_filter.is_blacklisted(s)
      if result:
        blacklisted_cnt += 1
        logger.debug('[ProductFiltered] ProductID: %s, Reason: Blacklisted - %s, Title: %s', prod.get('source_product_id', ''), result, s)
        continue

      to_upload_cnt += 1

      # Temporary remove categories
      prod.pop('categories', None)

      products_buf.append(prod)
      if len(products_buf) < batch_size:
        continue

      max_retries = 3
      while max_retries > 0:
        try:
          spree_api.import_products(products_buf, stock_location_id, shipping_category_id, vendor_id, merchant_id, min_shipping_days, taxonomy_name, tax_category_id)
          products_buf = []
          break
        except Exception as e:
          logger.exception(e)
          max_retries -= 1

  if products_buf:
    spree_api.import_products(products_buf, stock_location_id, shipping_category_id, vendor_id, merchant_id, min_shipping_days, taxonomy_name, tax_category_id)
  products_buf = []

  logger.info('[ProductAudit] Blacklisted: %s, ToUpload: %s', blacklisted_cnt, to_upload_cnt)


if __name__ == "__main__":
  import_products()

==> em_celery-0.1.46-py2.py3-none-any.whl: em_celery/tools/spree/product_importer.py <==
# -*- coding: utf-8 -*-

import datetime
import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.api import SpreeApi
from em_tasks.utils.blacklist_filter import BlacklistFilter
from em_tasks.store.models import *

from em_celery import logger, init_db


@click.command('Import products to Spree')
@click.option('-s', '--store_code', type=str, required=True)
@click.option('-ms', '--min_shipping_days', type=int, default=7, help='Minimum shipping days, default is 7.')
@click.option('-tn', '--taxonomy_name', type=str, default='Categories', help='Spree taxonomy name, default is "Categories".')
@click.option('-m', '--merchant_id', required=True, type=str, help='Google Merchant ID to upload to.')
@click.option('-v', '--vendor_id', required=True, type=str, help='Vendor ID that products belongs to.')
@click.option('-tc', '--tax_category_id', type=int, default=1, help='Spree tax category ID, default is 1.')
@click.option('-sl', '--stock_location_id', required=True, type=int, help='Spree stock location ID.')
@click.option('-sc', '--shipping_category_id', required=True, type=int, help='Spree shipping category ID.')
@click.option('-pl', '--min_price', type=float, default=40, help='Minimum product price, default is 40.')
@click.option('-ph', '--max_price', type=float, default=500, help='Maximum product price, default is 40.')
@click.argument('products_path')
def import_products(store_code, products_path, shipping_category_id, stock_location_id, merchant_id, vendor_id, tax_category_id=1, taxonomy_name='Categories', min_shipping_days=7, min_price=40, max_price=500):
  init_db()

  if not products_path:
    return

  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    return

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    return

  blacklist_filter = BlacklistFilter()

  credential = json.loads(store.api_credential)
  spree_api = SpreeApi(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
  # spree_api = SpreeApi('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))

  blacklisted_cnt = 0
  to_upload_cnt = 0

  batch_size = 50
  products_buf = []
  with open(products_path, encoding='utf-8', errors='ignore') as fh:
    for line in fh:
      s = line.strip()
      if not s:
        continue

      prod = None
      try:
        prod = json.loads(s)
      except Exception as e:
        logger.exception(e)

      if not prod:
        continue

      price = prod.get('price', None)
      if not price or price < min_price or price > max_price:
        continue

      brand = prod.get('brand', None)
      title = prod.get('title_en', None) or prod.get('title', '')
      if brand:
        s = '{} -{}'.format(brand.lower(), title.lower())
      else:
        s = title.lower()
      result = blacklist_filter.is_blacklisted(s)
      if result:
        blacklisted_cnt += 1
        logger.debug('[ProductFiltered] ProductID: %s, Reason: Blacklisted - %s, Title: %s', prod.get('source_product_id', ''), result, s)
        continue

      to_upload_cnt += 1

      # Temporary remove categories
      prod.pop('categories', None)

      products_buf.append(prod)
      if len(products_buf) < batch_size:
        continue

      max_retries = 3
      while max_retries > 0:
        try:
          spree_api.import_products(products_buf, stock_location_id, shipping_category_id, vendor_id, merchant_id, min_shipping_days, taxonomy_name, tax_category_id)
          products_buf = []
          break
        except Exception as e:
          logger.exception(e)
          max_retries -= 1

  if products_buf:
    spree_api.import_products(products_buf, stock_location_id, shipping_category_id, vendor_id, merchant_id, min_shipping_days, taxonomy_name, tax_category_id)
  products_buf = []

  logger.info('[ProductAudit] Blacklisted: %s, ToUpload: %s', blacklisted_cnt, to_upload_cnt)


if __name__ == "__main__":
  import_products()
